###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.1 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import Products
import OFS.Folder
import news_group_storage
import base_item
import nntplib
import string


news_host_add_redirect = HTMLFile('news_host_add_redirect', globals())
manage_add_news_host_form = HTMLFile('news_host_add', globals())


def manage_add_news_host(self, id, server, port, active_list, REQUEST=None):
    "Add an instance of the news_host class"

    self._setObject(id, news_host(id, server, port, active_list))

    if REQUEST is not None:

        return self.manage_main(self, REQUEST)


class news_host(
	Products.ZCatalog.CatalogAwareness.CatalogAware,
	OFS.Folder.Folder,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager,
	base_item.base_item
	):
	"Documentation string"

	meta_type = 'NewsHost'
	icon = 'misc_/Transform/Folder_icon.gif'

	_properties = (
		{'id':'server', 'type':'string'},
		{'id':'port', 'type':'int'},
		{'id':'active_list', 'type':'lines'},
		)

	meta_types = (
		{'name':'NewsGroupStorage',
		 'action':'manage_add_news_group_storage_form'},
		)

	manage_add_news_group_storage_form = news_group_storage.manage_add_news_group_storage_form
	manage_add_news_group_storage = news_group_storage.manage_add_news_group_storage
	news_group_storage_add_redirect = news_group_storage.news_group_storage_add_redirect

	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('Add NewsGroupStorage',
		 ('manage_add_news_group_storage',
		  'manage_add_news_group_storage_form')),
		('View NewsHosts',
		 ('',)),
		)

	index_html = HTMLFile('news_host_index', globals())


	def __init__(self, id, server='', port=None, active_list=''):
		"Initialize the class instance"

		self.id = id
		self.server = server
		self.port = port
		self.active_list = active_list

		self.index_object()

		connection = self.refresh()

		


	def refresh(self):
		"""Opens a connection."""

		if self.port:

			return nntplib.NNTP(self.server, self.port)

		else:

			return nntplib.NNTP(self.server)


	def get_subscribed_newsgroups(self):
		"""Returns a list of subscribed newsgroups."""

		newsgroups = []

		map(newsgroups.append, self.objectValues('NewsGroupStorage'))


		return newsgroups
		

	def retrieve_group(self, newsgroup):
		"""Retrieves messages for a given group."""

		connection = self.refresh()

		news_group_storage = self[newsgroup]

		dummy, dummy, first, last, dummy = connection.group(newsgroup)

		first = int(first)
		last = int(last)


		# If there are new messages.

		if last > news_group_storage.last_retrieved_message:

			# If the first (available) message on the newsserver
			# is more recent than then last message we retrieved
			# we can safely skip our own counter and start retrieving
			# based upon the message number supplied by the server.

			if first > news_group_storage.last_retrieved_message:

				message_retrieval_start = first

			else:

				message_retrieval_start = news_group_storage.last_retrieved_message

			for message_number in range(message_retrieval_start,
										last + 1):

				try:
					
					# Should we add more program logic here, WRT to
					# status codes, etc?

					article = string.join(
						connection.article(str(message_number))[-1],'\n')

					Products.RFC822Message.util.store_unparsed_message(
						news_group_storage, article)

					news_group_storage.last_retrieved_message = message_number

				except nntplib.error_temp:

					# Add program logic (handling of status, etc)
					# FIXME

					pass

		else:

			raise 'Yay', 'No new messages!'
				

	def retrieve(self):
		"""Retrieves new messages."""

		for newsgroup in self.get_subscribed_newsgroups():

			self.retrieve_group(newsgroup.id)


	def post(self, message):
		"""Posts a message."""

		connection = self.refresh()

		return connection.post(
			Products.RFC822Message.util.my_string_io(message))


default__class_init__(news_host)

