###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.2 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import MessageDialog
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import Products
import OFS.SimpleItem


rfc822_attachment_add_redirect = HTMLFile('rfc822_attachment_add_redirect', globals())
manage_add_rfc822_attachment_form = HTMLFile('rfc822_attachment_add', globals())

def manage_add_rfc822_attachment(self, id, data, headers, content_type, filename, REQUEST=None):
    "Add an instance of the rfc822_attachment class"


    self._setObject(id, rfc822_attachment(id, data, headers, content_type, filename))

    if REQUEST is not None:

        return self.manage_main(self, REQUEST)


class rfc822_attachment(
	Products.ZCatalog.CatalogAwareness.CatalogAware,
	OFS.SimpleItem.Item,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager
	):
	"Documentation string"

	meta_type = 'RFC822Attachment'
	icon = 'misc_/Transform/dtmldoc.gif'

	_properties = (
		{'id':'data', 'type':'text'},
		{'id':'content_type', 'type':'string'},
		{'id':'filename', 'type':'string'},
		)

	manage_options = (
		{'label':'Edit', 'action':'manage_main'},
		{'label':'View', 'action':''},
		)

	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('View Attachment',
		 ('','render_data')),
		)

	index_html = HTMLFile('rfc822_attachment_index', globals())
	manage_main = HTMLFile('rfc822_attachment_edit', globals())


	def __init__(self, id, data='', content_type='', filename='', headers={}):
		"Initialize the class instance"

		self.id = id
		self.data = data
		self.size = len(data)
		self.content_type = content_type
		self.filename = filename
		self.headers = {}

		self.index_object()


	def download(self, REQUEST=None, RESPONSE=None):
		"""Method for downloading / viewing attachment."""

		RESPONSE.setHeader('Content-Type', self.content_type)
		RESPONSE.setHeader('Content-Length', self.size)

		return self.data


	def set_header(self, header_name, header_value):
		"""Sets an attachment header."""

		self.headers[header_name] = header_value


	def manage_edit(self, data, headers, content_type, filename, REQUEST=None):
		"Change properties for the class instance."

		self.data = data
		self.headers = headers
		self.content_type = content_type
		self.filename = filename

		self.reindex_object()

		if REQUEST is not None:
			return MessageDialog(
			   title='Edited',
			   message="Properties for %s has been changed." % self.id,
			   action = "./manage_main"
			   )


	def render_data(self, REQUEST=None):
		"""For downloading.."""

		RESPONSE.add_header('content-type', self.content_type)
		RESPONSE.set_body(self.data)


default__class_init__(rfc822_attachment)

